==> libpicocontainer-java_2.3.orig.tar.gz: picocontainer-2.3/org/picocontainer/behaviors/Intercepting.java <==
/*****************************************************************************
 * Copyright (c) PicoContainer Organization. All rights reserved.            *
 * ------------------------------------------------------------------------- *
 * The software in this package is published under the terms of the BSD      *
 * style license a copy of which has been included with this distribution in *
 * the LICENSE.txt file.                                                     *
 *                                                                           *
 *****************************************************************************/
package org.picocontainer.behaviors;

import org.picocontainer.ComponentAdapter;
import org.picocontainer.ComponentMonitor;
import org.picocontainer.LifecycleStrategy;
import org.picocontainer.Parameter;
import org.picocontainer.PicoCompositionException;

import java.util.Map;
import java.util.HashMap;
import java.util.Properties;
import java.io.Serializable;


/** @author Paul Hammant */
public class Intercepting extends AbstractBehaviorFactory {
    private static final long serialVersionUID = 8186483610012094244L;

    public <T> ComponentAdapter<T> createComponentAdapter(ComponentMonitor componentMonitor,
                                                          LifecycleStrategy lifecycleStrategy,
                                                          Properties componentProperties,
                                                          Object componentKey,
                                                          Class<T> componentImplementation,
                                                          Parameter... parameters) throws PicoCompositionException {
        return new Intercepted(super.createComponentAdapter(componentMonitor,
                                                            lifecycleStrategy, componentProperties, componentKey,
                                                            componentImplementation, parameters));
    }
}

==> libpicocontainer-java_2.4.orig.tar.gz: picocontainer-2.4/org/picocontainer/behaviors/Intercepting.java <==
/*****************************************************************************
 * Copyright (c) PicoContainer Organization. All rights reserved.            *
 * ------------------------------------------------------------------------- *
 * The software in this package is published under the terms of the BSD      *
 * style license a copy of which has been included with this distribution in *
 * the LICENSE.txt file.                                                     *
 *                                                                           *
 *****************************************************************************/
package org.picocontainer.behaviors;

import org.picocontainer.ComponentAdapter;
import org.picocontainer.ComponentMonitor;
import org.picocontainer.LifecycleStrategy;
import org.picocontainer.Parameter;
import org.picocontainer.PicoCompositionException;

import java.util.Properties;


/** @author Paul Hammant */
@SuppressWarnings("serial")
public class Intercepting extends AbstractBehaviorFactory {

    public <T> ComponentAdapter<T> createComponentAdapter(ComponentMonitor componentMonitor,
                                                          LifecycleStrategy lifecycleStrategy,
                                                          Properties componentProperties,
                                                          Object componentKey,
                                                          Class<T> componentImplementation,
                                                          Parameter... parameters) throws PicoCompositionException {
        return new Intercepted(super.createComponentAdapter(componentMonitor,
                                                            lifecycleStrategy, componentProperties, componentKey,
                                                            componentImplementation, parameters));
    }
}
